# Papyrus

Geospatial Extensions for the [Pyramid](http://docs.pylonsproject.org/en/latest/docs/pyramid.html) web framework.

The Papyrus doc is hosted on [Read the Docs](http://readthedocs.org/).

- Doc for current stable release: http://papyrus.readthedocs.org/en/stable/
- Doc for current master branch: http://papyrus.readthedocs.org/en/latest/
